@@ -500,6 +500,41 @@ is_num_char_fact <- function(x) {
 }
 
 
+#' Format method descriptions
+#'
+#' This function formats method descriptions by combining method names and their descriptions.
+#'
+#' @param method A named list of methods and their descriptions.
+#' @return A character vector of formatted method descriptions.
+#' @details If any non-atomic elements are present in the method list, they are converted to
+#' a string representation using `dput()`.
+format_method_descriptions <- function(method) {
+    assertthat::assert_that(is.list(method))
+
+    is_atomic <- vapply(method, is.atomic, logical(1))
+    if (any(!is_atomic)) {
+        method[!is_atomic] <- lapply(
+            method[!is_atomic],
+            function(x) {
+                paste(
+                    capture.output(dput(x)),
+                    collapse = "\n    "
+                )
+            }
+        )
+    }
+    vapply(
+        mapply(
+            function(x, y) sprintf("    %s: %s", y, x),
+            method,
+            names(method),
+            USE.NAMES = FALSE,
+            SIMPLIFY = FALSE
+        ),
+        identity,
+        character(1)
+    )
+}
 
 #' Convert object to dataframe
 #'
@@ -556,11 +591,30 @@ clear_model_cache <- function(cache_dir = getOption("rbmi.cache_dir")) {
     unlink(files)
 }
 
+
 #' Get Compiled Stan Object
 #'
 #' Gets a compiled Stan object that can be used with `rstan::sampling()`
 #' @keywords internal
 get_stan_model <- function() {
+
+    # Compiling Stan models updates the current seed state. This can lead to
+    # non-reproducibility as compiling is conditional on wether there is a cached
+    # model available or not. Thus we save the current seed state and restore it
+    # at the end of this function so that it is in the same state regardless of
+    # whether the model was compiled or not.
+    # See https://github.com/insightsengineering/rbmi/issues/469
+    # Note that .Random.seed is only set if the seed has been set or if a random number
+    # has been generated.
+    current_seed_state <- globalenv()$.Random.seed
+    on.exit({
+        if (is.null(current_seed_state) && exists(".Random.seed", envir = globalenv())) {
+            rm(".Random.seed", envir = globalenv(), inherits = FALSE)
+        } else {
+            assign(".Random.seed", value = current_seed_state, envir = globalenv(), inherits = FALSE)
+        }
+    })
+
     ensure_rstan()
     local_file <- file.path("inst", "stan", "MMRM.stan")
     system_file <- system.file(file.path("stan", "MMRM.stan"), package = "rbmi")
@@ -574,17 +628,19 @@ get_stan_model <- function() {
     cache_dir <- getOption("rbmi.cache_dir")
     dir.create(cache_dir, showWarnings = FALSE, recursive = TRUE)
     model_file <- file.path(cache_dir, paste0("MMRM_", get_session_hash(), ".stan"))
-    
+
     if (!file.exists(model_file)) {
         clear_model_cache()
         file.copy(file_loc, model_file, overwrite = TRUE)
     }
-    
-    rstan::stan_model(
+
+    model <- rstan::stan_model(
         file = model_file,
         auto_write = TRUE,
         model_name = "rbmi_mmrm"
     )
+
+    return(model)
 }
 
 
@@ -603,8 +659,18 @@ get_stan_model <- function() {
 #'
 #' Default = `tools::R_user_dir("rbmi", which = "cache")`
 #'
-#' Directory to store compiled Stan model in. If not set, a temporary directory is used for
-#' the given R session. Can also be set via the environment variable `RBMI_CACHE_DIR`.
+#' Directory to store compiled Stan models in to avoid having to re-compile.
+#' If the environment variable `RBMI_CACHE_DIR` has been set this will be used
+#' as the default value.
+#' Note that if you are running rbmi in multiple R processes at the same time
+#' (that is say multiple calls to `Rscript` at once) then there is a theoretical
+#' risk of the processes breaking each other as they attempt to read/write to the
+#' same cache folder at the same time. To avoid this potential issue it is recommended
+#' to set the cache directory to a unique folder for each R session e.g.
+#'
+#' ```
+#' options("rbmi.cache_dir" = tempdir(check = TRUE))
+#' ```
 #'
 #'
 #' @examples
